@@ -1058,7 +1058,7 @@ static const SECTION union { const guint8 data[8392]; const double alignment; vo
   0x69, 0x6e, 0x73, 0x2f, 0x04, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { gedit_sort_resource_data.data, sizeof (gedit_sort_resource_data.data) };
+static GStaticResource static_resource = { gedit_sort_resource_data.data, sizeof (gedit_sort_resource_data.data), NULL, NULL, NULL };
 extern GResource *gedit_sort_get_resource (void);
 GResource *gedit_sort_get_resource (void)
 {
